<?php
/**
 * Installationsklasse
 *
 * @package     Expblog
 * @category    Installation
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.3
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class INSTALL {

  public  $sql;
  private $dbms;
  private $prefix;
  public  $database;
  private $mysqlconf  = '../system/sqlconf.php';
  private $expconf    = '../system/expconf.php';
  private $sqlitefile = '../system/expblog.sqlite.db';
  private $sqlitedb   = 'expblog';
  private $rpchosts = array(
            array(0 => "Technorati", 1 => "http://rpc.technorati.com/rpc/ping"),
            array(0 => "Feedburner", 1 => "http://ping.feedburner.com/index.php"),
            array(0 => "Blogg.de", 1 => "http://www.blogg.de/ping.php")
  );
  private $tables = array(
            "user"          => "user",
            "kategorien"    => "kategorien",
            "kommentare"    => "kommentare",
            "news"          => "news",
            "warteschlange" => "warteschlange",
            "blogroll"      => "blogroll",
            "rpcping"       => "rpcping",
            "counter"       => "counter"
  );


  /**
   * Konstruktor
   *
   * @return   void
   * @access   public
   */
  public function __construct()
  {
    $this->dbms = $_SESSION['dbms'];
    if($this->dbms === 'mysql')
    {
      $this->sql = new MYSQL;
      $this->sql->connect($_SESSION['database'], $_SESSION['host'], $_SESSION['username'], $_SESSION['password']); 
      $this->database = $_SESSION['database'];  
      $this->prefix = $_SESSION['prefix'];   
    }
    elseif($this->dbms === 'sqlite')
    {
      $this->sql = new SQLITE;
      $this->sql->connect($this->sqlitefile, false, false, false);
      $this->database = $this->sqlitedb; 
      $this->prefix = 'expblog_';
    }   
    foreach($this->tables as $array => $value)
    {
      $this->tables[$array] = $this->prefix.$value;
    }
  }


  /**
   * Anlegen der Expblog Tabellen.
   *
   * @return   bool
   * @access   public
   */
  public function createExpblogTables()
  {
    if($_SESSION['dbms'] === 'mysql')
    {
      if(!$this->createUserTable())
      {
        return false;
      }
      if(!$this->createNewsTable())
      {
        return false;
      }
      if(!$this->createKategorieTable())
      {
        return false;
      }
      if(!$this->createKommentarTable())
      {
        return false;
      }
      if(!$this->createWarteschlangenTable())
      {
        return false;
      }
      if(!$this->createBlogrollTable())
      {
        return false;
      }
      if(!$this->createRPCPingTable())
      {
        return false;
      }
      if(!$this->createCounterTable())
      {
        return false;
      }      
    }
    return true;
  }


  /**
   * Anlegen der Usertabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createUserTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['user']}
            (
              id tinyint(3) unsigned NOT NULL AUTO_INCREMENT,
              name varchar(50) NOT NULL,
              password varchar(33) NOT NULL,
              level tinyint(1) unsigned NOT NULL default '0',
              sid varchar(33) NOT NULL default '0',
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";   
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }

  /**
   * Anlegen der Newstabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createNewsTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['news']}
            (
              id SMALLINT(5) unsigned NOT NULL AUTO_INCREMENT,
              timestamp INT(10) unsigned NOT NULL,
              userid tinyint(3) unsigned NOT NULL,
              kategorie tinyint(3) unsigned NOT NULL,
              titel varchar(100) NOT NULL,
              teaser mediumtext NOT NULL,
              nachricht longtext NOT NULL,
              ip tinytext NOT NULL,
              startsite tinyint(1) unsigned NOT NULL,
              published tinyint(1) unsigned NOT NULL,
              hits smallint(5) unsigned NOT NULL default '0',
              INDEX(startsite),
              INDEX(published),
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Anlegen der Kategorientabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createKategorieTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['kategorien']}
            (
              id SMALLINT(5) unsigned NOT NULL AUTO_INCREMENT,
              name tinytext NOT NULL,
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Anlegen der Kommentartabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createKommentarTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['kommentare']}
            (
              id SMALLINT(5) unsigned NOT NULL AUTO_INCREMENT,
              news SMALLINT(6) NOT NULL,
              parentid SMALLINT(5) unsigned NOT NULL,
              kommentar longtext NOT NULL,
              name tinytext NOT NULL,
              timestamp int(11) NOT NULL,
              ip tinytext NOT NULL,
              homepage mediumtext NOT NULL,
              INDEX(news),
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Anlegen der Warteschlangentabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createWarteschlangenTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['warteschlange']}
            (
              id smallint(5) unsigned NOT NULL AUTO_INCREMENT,
              timestamp int(10) unsigned NOT NULL,
              userid tinyint(3) unsigned NOT NULL,
              kategorie tinyint(3) unsigned NOT NULL,
              titel varchar(100) NOT NULL,
              teaser mediumtext NOT NULL,
              nachricht longtext NOT NULL,
              ip tinytext NOT NULL,
              startsite tinyint(1) unsigned NOT NULL,
              published tinyint(1) unsigned NOT NULL,
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Anlegen der Blogrolltabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createBlogrollTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['blogroll']}
            (
              id SMALLINT(5) unsigned NOT NULL AUTO_INCREMENT,
              url tinytext NOT NULL,
              titel tinytext NOT NULL,
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Anlegen der RPCPingtabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createRPCPingTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['rpcping']}
            (
              id SMALLINT(5) unsigned NOT NULL AUTO_INCREMENT,
              url tinytext NOT NULL,
              titel tinytext NOT NULL,
              PRIMARY KEY (id)
            ) CHARACTER SET latin1 COLLATE latin1_german1_ci TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Anlegen der Countertabelle.
   *
   * @return   bool
   * @access   private
   */
  private function createCounterTable()
  {
    $sql = "CREATE TABLE
             {$this->tables['counter']}
            (
              id mediumint(8) unsigned NOT NULL auto_increment,
              timestamp int(10) unsigned NOT NULL,
              ip tinytext NOT NULL,
              newsid smallint(5) unsigned NOT NULL,
              PRIMARY KEY (id)
            ) TYPE=MyISAM;";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Demoeintrge schreiben.
   *
   * @return   bool
   * @access   public
   */
  public function writeDemoContent()
  {
    if(!$this->writeRPCHosts())
    {
      return false;
    }
    if(!$this->createDemoCategory())
    {
      return false;
    }
    if(!$this->createDemoPost())
    {
      return false;
    }
    return true;
  }


  /**
   * Standardeintrge in die RPC Tabelle schreiben.
   *
   * @return   bool
   * @access   private
   */
  private function writeRPCHosts()
  {
    foreach($this->rpchosts as $service)
    {
      $sql = "INSERT INTO
               {$this->tables['rpcping']}
              (url, titel)
              VALUES
              (
                '{$service[1]}',
                '{$service[0]}'
              )";
      if(false === ($res = $this->sql->query($sql)))
      {
        return false;
      }
    }
    return true;
  }


  /**
   * Demo Kategorie erstellen.
   *
   * @return   bool
   * @access   private
   */
  private function createDemoCategory()
  {
    $sql = "INSERT INTO
             {$this->tables['kategorien']}
            (name)
            VALUES ('Demo')";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Demopost erstellen.
   *
   * @return   bool
   * @access   private
   */
  private function createDemoPost()
  {
    $welcometext = '<b>Hinweis:</b> Weitere Einstellungs- und Verwaltungsmglichkeiten zum Blog finden Sie im <a href="'.WEBPATH.'admin/login.php">Administrationsbereich</a>. Dort knnen Sie smtliche Inhalte des Blogs verwaltet und weitere (Detail-)Einstellungen vornehmen. Aus technischen Grnden sind die Weblinks nicht ber den Administrationsbereich verwaltbar. Sie knnen diese jedoch in der Datei plugins/weblinks.php editieren.';
    $sql = "INSERT INTO
             {$this->tables['news']}
            (timestamp, userid, kategorie, titel, teaser, nachricht, ip, startsite, published)
            VALUES
            (
              ".time().",
              1,
              1,
              'Willkommen beim eXpBlog ".VERSION."',
              '{$welcometext}',
              '',
              '127.0.0.1',
              1,
              1
            )";
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Benutzerkonto des Blogbesitzers anlegen.
   *
   * @param    string $name Benutzername des Blogbesitzers
   * @param    string $password Passwort des Blogbesitzers
   * @return   bool
   * @access   public
   */
  public function createOwnerAccount($username='admin', $password='qwertz')
  {
    $sql = "INSERT INTO
             {$this->tables['user']}
            (name, password, level)
            VALUES
            ('{$username}', '".md5($password)."', 3)";      
    if(false === ($res = $this->sql->query($sql)))
    {
      return false;
    }
    return true;
  }


  /**
   * Konfigurationsdatei(n) schreiben. (system/expconf.php bzw. system/mysqlconf.php)
   *
   * @return   bool
   * @access   public
   */
  public function writeConfig($expconf)
  {
    if(!$this->writeExpConf($expconf))
    {
      return false;
    }
    if(!$this->writeSQLConf())
    {
      return false;
    }
    return true;
  }


  /**
   * MYSQL Konfigurationsdatei schreiben. (system/mysqlconf.php)
   *
   * @return   bool
   * @access   private
   */
  private function writeSQLConf()
  {
    if(false !== ($mysqlfile = @ fopen($this->mysqlconf, "wb")))
    {
      $mysqlconf  = '<?php'."\n";
      $mysqlconf .= '/* MYSQL Zugangsdaten */'."\n";
      $mysqlconf .= 'define("HOST", "'.$_SESSION['host'].'");'."\n";
      $mysqlconf .= 'define("DATABASE", "'.$_SESSION['database'].'");'."\n";
      $mysqlconf .= 'define("USERNAME", "'.$_SESSION['username'].'");'."\n";
      $mysqlconf .= 'define("PASSWORD", "'.$_SESSION['password'].'");'."\n";
      $mysqlconf .= 'define("PREFIX", "'.$this->prefix.'");'."\n";
      $mysqlconf .= "\n";
      $mysqlconf .= '/* Expblog Datenbank Tabellennamen */'."\n";
      foreach($this->tables as $key => $value)
      {
        $mysqlconf .= 'define("DB_TABLE_'.$key.'", "'.$value.'");'."\n";               
      }
      $mysqlconf .= '?>';
      fputs($mysqlfile, $mysqlconf);
      fclose($mysqlfile);
      return true;
    }
    return false;
  }


  /**
   * Expblog Konfigurationsdatei schreiben. (system/expconf.php)
   *
   * @return   bool
   * @access   private
   */
  private function writeExpConf($expconf)
  {
    if(false !== ($expconffile = @ fopen($this->expconf, "wb")))
    {
      $expconf['blogtitel'] = $_POST['blogtitel'];
      $expconf['impstatus'] = $_POST['impstatus'];
      $expconf['impname']   = $_POST['impname'];
      $expconf['impstr']    = $_POST['impstr'];
      $expconf['impplzort'] = $_POST['impplzort'];
      $expconf['impemail']  = $_POST['impemail'];
      $expconf['dbms']  = $_SESSION['dbms'];
      $conf  = '<?php'."\n";
      $conf .= '/* Expblog Konstanten */'."\n";
      $conf .= 'define("WEBPATH", "'.$_POST['webpath'].'");'."\n";
      $conf .= 'define("ABSPATH", "'.$_POST['abspath'].'");'."\n";
      $conf .= 'define("INITIME", "'.time().'");'."\n";
      $conf .= 'define("VERSION", "'.VERSION.'");'."\n";
      $conf .= "\n";
      $conf .= '/* Expblog Konfiguration */'."\n";
      foreach($expconf as $key => $value)
      {
        if(is_numeric($value) || is_bool($value))
        {
          $conf .= "\$expconf['".$key."'] = ".$value.";\n";
        }
        else
        {
          $conf .= "\$expconf['".$key."'] = '".$value."';\n";
        }
      }
      $conf .= '?>';
      fputs($expconffile, $conf);
      fclose($expconffile);
      return true;
    }
    return false;
  }


  /**
   * berprfung ob die Tabellen bereits existieren.
   *
   * @return   bool
   * @access   public
   */
  public function checkIfTablesExists()
  {
    $res = $this->sql->query("SHOW TABLES FROM ".$this->database." LIKE '".$this->prefix."%'");
    if(count($res) > 0)
    {
      $dtables = array();
      foreach($res as $key => $value)
      {
        array_push($dtables, $value[0]);
      }      
      $doubles = array_intersect($dtables, $this->tables);
      if($doubles > 0)
      {
        return $doubles;
      }
    }   
    return false;
  }


  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}

}
?>
