<?php
/**
 * Plugin fr die Seitenleiste zum Generieren eines Zufallsposts
 *
 * @package     Expblog
 * @category    Plugins
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */

/**
 * Hauptfunktion des Plugins
 *
 * @param    object $output  Referenz(keine Kopie!) auf das Output Objekt
 * @param    array  $lang    Array der aus der aktuell verwendeten Sprachdatei
 * @param    array  $post    Kopie von $_POST
 * @param    array  $get     Kopie von $_GET
 * @return   void
 */
function zufallspost($output, $lang, $post, $get)
{
  /**
   * Diese Funktion liefert entweder ein Array mit einem Zufallsergebnis oder false
   *
   * @param    object $output    Referenz(keine Kopie!) auf das Output Objekt
   * @param    int    $maxtries  Anzahl der maximalen Versuche, nach denen die Funktion false zurckgiebt (Default 3)
   * @return   array|bool
   */
  function randp($output, $maxtries)
  {
    $expblog_news = DB_TABLE_news;
    $expblog_kategorien = DB_TABLE_kategorien;
    if($output->config['dbms'] === 'mysql')
    {
      $res = $output->sql->query("
        SELECT
          news.id AS id,
          news.titel AS titel,
          kategorien.name AS kategorie,
          news.timestamp AS timestamp
        FROM
          {$expblog_news} AS news
        LEFT JOIN
          {$expblog_kategorien} AS kategorien
        ON
          news.kategorie = kategorien.id
        WHERE
          news.published = 1
        ORDER BY
          RAND()
        LIMIT 1
      ");
    }
    elseif($output->config['dbms'] === 'sqlite')
    {
      $res = $output->sql->query("
        SELECT
          news.id AS id,
          news.titel AS titel,
          kategorien.name AS kategorie,
          news.timestamp AS timestamp
        FROM
          {$expblog_news} AS news
        LEFT JOIN
          {$expblog_kategorien} AS kategorien
        ON
          news.kategorie = kategorien.id
        WHERE
          news.published = 1
        ORDER BY
          RANDOM()
        LIMIT 1
      ");
    }

    if($res === false)
    {
      return false;
    }
    elseif(empty($res['titel']) && count($res) > 1 && $maxtries > 0)
    {
      return randp($output, $maxtries-1);
    }

    return $res;
  }
?>
  <!-- Anfang ZUFALLSPOST Plugin -->
  <div id="plugin_zufallspost">
    <p id="plugin_zufallspost_topic"><?=$lang['plugins']['zufallspost']['title']?></p>
    <?php
      $maxtries = 3;
      $randpost = randp($output, $maxtries);
      if($randpost)
      {
        if($output->config['modrewrite'])
        {
          $jahr = date("Y", $randpost[0]['timestamp']);
          $monat = date("m", $randpost[0]['timestamp']);
          $tag = date("d", $randpost[0]['timestamp']);
          echo '<div id="plugin_zufallspost_content"><a href="'.WEBPATH.'archiv/'.$jahr.'/'.$monat.'/'.$tag.'/'.$randpost[0]['id'].'-'.$output->string2urlstring($randpost[0]['titel']).'">'.$randpost[0]['titel'].'</a><br />('.$randpost[0]['kategorie'].')</div>';
        }
        else
        {
          echo '<div id="plugin_zufallspost_content"><a href="'.WEBPATH.'details.php?id='.$randpost[0]['id'].'">'.$randpost[0]['titel'].'</a><br />('.$randpost[0]['kategorie'].')</div>';
        }
      }
      else
      {
        echo '<div id="plugin_zufallspost_content">'.$lang['plugins']['zufallspost']['error'].'</div>';
      }
    ?>
  </div>
  <!-- Ende ZUFALLSPOST Plugin -->
<?php } ?>
