<?php
/**
 * Artikel Klasse.
 *
 * Diese Klasse bietet alle ntigen Werkzeuge um die Artikel auszulesen und zu verwalten.
 * Wird von Front- und Backend genutzt.
 * @package     Expblog
 * @category    Frontend|Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.2
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class ARTIKEL
{
  /**
   * Kopie von DB_TABLE_news
   * @var string
   */
  private $expblog_news;
  /**
   * Kopie von DB_TABLE_warteschlange
   * @var string
   */
  private $expblog_warteschlange;
  /**
   * Kopie von DB_TABLE_kommentare
   * @var string
   */
  private $expblog_kommentare;
  /**
   * Kopie von DB_TABLE_user
   * @var string
   */
  private $expblog_user;
  /**
   * Kopie von DB_TABLE_kategorien
   * @var string
   */
  private $expblog_kategorien;
  /**
   * Benutzer ID / Kopie von $_SESSION['userid']
   * @var int
   */
  public  $userid;
  /**
   * Benutzerlevel des Autors / Kopie $_SESSION['userlevel']
   * @var int
   */
  public  $userlevel;
  /**
   * IP des Autors
   * @var string
   */
  public  $ip;
  /**
   * Zeitstempel der Erstellung des Artikels
   * @var int
   */
  public  $timestamp;
  /**
   * Sortiermodus(auf-/absteigend) der Artikel beim Auslesen
   * @var string
   */
  public  $sort;
  /**
   * Referenz auf das $output Objekt des Blogs
   * @var reference|object
   */
  public  $output;

  /**
   * Konstruktor
   *
   * @param    reference|object $output Referenz auf das $output Objekt des Blogs
   * @return   void
   * @access   public
   */
  public function __construct($output)
  {
    $this->output = $output;
    $this->expblog_news = DB_TABLE_news;
    $this->expblog_warteschlange  = DB_TABLE_warteschlange;
    $this->expblog_kommentare = DB_TABLE_kommentare;
    $this->expblog_user = DB_TABLE_user;
    $this->expblog_kategorien = DB_TABLE_kategorien;
    $this->userid = $_SESSION['userid'];
    $this->userlevel = $_SESSION['userlevel'];
    $this->ip = $_SERVER['REMOTE_ADDR'];
    $this->timestamp = time();
  }

  /**
   * Funktion zum Hinzufgen eines Artikels
   *
   * @param    int    $kategorie  Kategorie des Artikels
   * @param    string $titel      berschrift(Titel) des Artikels
   * @param    string $teaser     Anreisser(Teaser) des Artikels
   * @param    string $nachricht  Nachricht(Body) des Artikels
   * @param    int    $timestamp  Zeitstempel der Erstellung des Artikels
   * @param    int    $startseite Flag ob der Artikel auf der Startseite angezeigt werden soll. (Default=1)
   * @param    int    $published  Flag ob der Artikel als verffentlicht gelten soll. (Default=1)
   * @return   bool
   * @access   public
   */
  public function add($kategorie, $titel, $teaser, $nachricht, $timestamp, $startseite=1, $published=1)
  {
    $res = $this->output->sql->query("
      INSERT INTO
        {$this->expblog_news}
      (
        timestamp,
        userid,
        kategorie,
        titel,
        teaser,
        nachricht,
        ip,
        startsite,
        published
      )
      VALUES
      (
        {$this->timestamp},
        {$this->userid},
        {$kategorie},
        '{$titel}',
        '{$teaser}',
        '{$nachricht}',
        '{$this->ip}',
        {$startseite},
        {$published}
      )
    ");
    if(is_array($res) || $res === true)
    {
      if($this->output->config['rpcstatus'])
      {
        $rpcping = new RPCPING($this->output);
        $status = $rpcping->ping();
      }
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Hinzufgen eines Artikels in die Warteschlange. Zeitgesteiertes Posten.
   *
   * @param    int    $kategorie  Kategorie des Artikels
   * @param    string $titel      berschrift(Titel) des Artikels
   * @param    string $teaser     Anreisser(Teaser) des Artikels
   * @param    string $nachricht  Nachricht(Body) des Artikels
   * @param    int    $timestamp  Zeitstempel der Erstellung des Artikels
   * @param    int    $startseite Flag ob der Artikel auf der Startseite angezeigt werden soll. (Default=1)
   * @return   bool
   * @access   public
   */
  public function addWS($kategorie, $titel, $teaser, $nachricht, $timestamp, $startseite=1, $published=0)
  {
    $res = $this->output->sql->query("
      INSERT INTO
        {$this->expblog_warteschlange}
      (
        timestamp,
        userid,
        kategorie,
        titel,
        teaser,
        nachricht,
        ip,
        startsite,
        published
      )
      VALUES
      (
        {$timestamp},
        {$this->userid},
        {$kategorie},
        '{$titel}',
        '{$teaser}',
        '{$nachricht}',
        '{$this->ip}',
        {$startseite},
        {$published}
      )
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Lschen eines Artikels
   *
   * @param    int $artikel_id  ID des zu lschenden Artikels
   * @return   bool
   * @access   public
   */
  public function delete($artikel_id)
  {
    $res1 = "
      DELETE FROM
        {$this->expblog_news}
      WHERE
        id = {$artikel_id}
      AND
      (
        userid = {$this->userid}
      OR
        {$this->userlevel} > 0
      )
    ";

    $res2 = "
      DELETE FROM
        {$this->expblog_kommentare}
      WHERE
        news = {$artikel_id}
      AND
        {$this->userlevel} > 0
    ";

    if(false !== ($this->output->sql->query($res1)) && false !== ($this->output->sql->query($res2)))
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Lschen eines Artikels aus der Warteschlange
   *
   * @param    int $artikel_id  ID des zu lschenden Artikels
   * @return   bool
   * @access   public
   */
  public function deleteWS($artikel_id)
  {
    $sql = "
        DELETE FROM
          {$this->expblog_warteschlange}
        WHERE
          id = {$artikel_id}
        AND
        (
          userid = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
    ";

    if(false === ($res = $this->output->sql->query($sql)))
    {
      return false;
    }
    return true;
  }

  /**
   * Funktion zum Lschen mehrerer Artikel
   *
   * @param    array $artikel_ids  Array mit den IDs der zu lschenden Artikel
   * @return   bool
   * @access   public
   */
  public function multiDelete($artikel_ids)
  {
    $res1 = "
        DELETE FROM
          {$this->expblog_news}
        WHERE
          id
        IN
          ({$artikel_ids})
        AND
        (
          userid = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
    ";

    $res2 = "
        DELETE FROM
          {$this->expblog_kommentare}
        WHERE
          news
        IN
          ({$artikel_ids})
        AND
          {$this->userlevel} > 0
    ";

    if(false !== ($this->output->sql->query($res1)) && false !== ($this->output->sql->query($res2)))
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Updaten eines Artikels
   *
   * @param    int    $artikel_id ID des Artikels
   * @param    int    $kategorie  Kategorie des Artikels
   * @param    string $titel      berschrift(Titel) des Artikels
   * @param    string $teaser     Anreisser(Teaser) des Artikels
   * @param    string $nachricht  Nachricht(Body) des Artikels
   * @param    int    $timestamp  Zeitstempel der Erstellung des Artikels
   * @param    int    $startseite Flag ob der Artikel auf der Startseite angezeigt werden soll. (Default=1)
   * @param    int    $published  Flag ob der Artikel als verffentlicht gelten soll. (Default=1)
   * @return   bool
   * @access   public
   */
  public function update($artikel_id, $kategorie, $titel, $teaser, $nachricht, $timestamp, $startseite=1, $published=1)
  {
    $query = "
      UPDATE
        {$this->expblog_news}
      SET
        kategorie = {$kategorie},
        titel = '{$titel}',
        teaser = '{$teaser}',
        nachricht = '{$nachricht}',
        timestamp = {$timestamp},
        startsite = {$startseite},
        published = {$published}
      WHERE
        id        = {$artikel_id}
      AND
      (
        userid    = {$this->userid}
      OR
        {$this->userlevel} > 0
      )
    ";

    if(false !== ($this->output->sql->query($query)))
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Updaten der Kategoriezugehrigkeit mehrerer Artikel
   *
   * @param    int    $artikel_ids IDs der Artikel
   * @param    int    $kategorie  Neue Kategorie der Artikel
   * @return   bool
   * @access   public
   */
  public function multiUpdate($artikel_ids, $kategorie)
  {
    $query = "
      UPDATE
        {$this->expblog_news}
      (kategorie)
      VALUES
      ('{$kategorie}')
      WHERE
        id
      IN
        ({$artikel_id})
      AND
      (
        userid    = {$this->userid}
      OR
        {$this->userlevel} > 0
      )
    ";

    if(false !== ($this->output->sql->query($query)))
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Verschieben/Freischalten eines Artikels aus der Warteschlange in die News Tabelle.
   *
   * @param    int    $artikel_id ID des Artikels
   * @return   bool
   * @access   public
   */
  public function moveWS($artikel_id)
  {
    $read = $this->getWS($artikel_id);
    $row = $read[0];
    $write = "
      INSERT INTO
        {$this->expblog_news}
      (
        timestamp,
        userid,
        kategorie,
        titel,
        teaser,
        nachricht,
        ip,
        startsite,
        published
      )
      VALUES
      (
        {$row['timestamp']},
        {$row['userid']},
        {$row['kategorie']},
        '{$row['titel']}',
        '{$row['teaser']}',
        '{$row['nachricht']}',
        '{$row['ip']}',
        {$row['startsite']},
        1
      )
    ";
    $delete = $this->deleteWS($artikel_id);
    if($read && false !== ($res = $this->output->sql->query($write)))
    {
      if($this->output->config['rpcstatus'])
      {
        $rpcping = new RPCPING($this->output);
        $ping = $rpcping->ping();
      }
      if($this->output->config['rssstatus'])
      {
        $rssfeed = new RSS($this->output);
        $feed = $rssfeed->makeFeed();
      }
      return true;
    }
    else
    {
      return false;
    }
  }

  /**
   * Funktion zum Abrufen eines Artikels
   *
   * @param    int    $artikel_id ID des Artikels
   * @return   array
   * @access   public
   */
  public function get($artikel_id)
  {
    $res = $this->output->sql->query("
      SELECT
        *
      FROM
        {$this->expblog_news}
      WHERE
        id = {$artikel_id}
      AND
      (
        userid = {$this->userid}
      OR
        {$this->userlevel} > 0
      )
    ");
    return $res;
  }

  /**
   * Funktion zum Abrufen eines Artikels aus der Warteschlange
   *
   * @param    int    $artikel_id ID des Artikels
   * @return   array
   * @access   public
   */
  public function getWS($artikel_id)
  {
    $res = $this->output->sql->query("
      SELECT
        *
      FROM
        {$this->expblog_warteschlange}
      WHERE
        id = {$artikel_id}
      AND
      (
        userid = {$this->userid}
      OR
        {$this->userlevel} > 0
        )
    ");
    return $res;
  }

  /**
   * Funktion zum Abrufen von mehreren Artikeln,
   * abhngig von den Benutzerrechten und einem Limit.
   *
   * @param    int    $limit_start Startwert fr die Bltterfunktion
   * @param    int    $limit_ende  Endwert fr die Bltterfunktion
   * @return   array
   * @access   public
   */
  public function getLimited($limit_start, $limit_ende)
  {
    $res = $this->output->sql->query("
      SELECT
        news.id,
        news.timestamp,
        kategorie.name AS name,
        news.titel,
        news.teaser,
        news.ip,
        news.startsite,
        news.published,
        user.name AS username,
        COUNT(kommentare.id) AS comments
      FROM
        {$this->expblog_news}
      AS
        news
      LEFT JOIN
        {$this->expblog_kommentare}
      AS
        kommentare
      ON
        kommentare.news = news.id
      LEFT JOIN
        {$this->expblog_user}
      AS
        user
      ON
        news.userid = user.id
      LEFT JOIN
        {$this->expblog_kategorien}
      AS
        kategorie
      ON
        news.kategorie = kategorie.id
      WHERE
        user.id = {$this->userid}
      OR
        {$this->userlevel} > 0
      GROUP BY
        news.timestamp
      ORDER BY
        news.timestamp
      {$this->sort}
      LIMIT
        {$limit_start},{$limit_ende}
    ");
    return $res;
  }

  /**
   * Funktion zum Abrufen von mehreren Artikeln aus der Warteschlange,
   * abhngig von den Benutzerrechten und einem Limit.
   *
   * @param    int    $limit_start Startwert fr die Bltterfunktion
   * @param    int    $limit_ende  Endwert fr die Bltterfunktion
   * @return   array
   * @access   public
   */
  public function getLimitedWS($limit_start, $limit_ende)
  {
    $res = $this->output->sql->query("
      SELECT
        news.id,
        news.timestamp,
        kategorie.name AS name,
        news.titel,
        news.teaser,
        news.ip,
        news.startsite,
        user.name AS username,
        COUNT(kommentare.id) AS comments
      FROM
        {$this->expblog_warteschlange}
      AS
        news
      LEFT JOIN
        {$this->expblog_kommentare}
      AS
        kommentare
      ON
        kommentare.news = news.id
      LEFT JOIN
        {$this->expblog_user}
      AS
        user
      ON
        news.userid = user.id
      LEFT JOIN
        {$this->expblog_kategorien}
      AS
        kategorie
      ON
        news.kategorie = kategorie.id
      WHERE
        user.id = {$this->userid}
      OR
        {$this->userlevel} > 0
      GROUP BY
        news.timestamp
      ORDER BY
        news.timestamp
      ASC
      LIMIT
        {$limit_start},{$limit_ende}
    ");
    return $res;
  }

  /**
   * Funktion zum Abrufen von mehreren Artikel IDs,
   * abhngig von den Benutzerrechten und einem Limit.
   *
   * @param    int    $limit_start Startwert fr die Bltterfunktion
   * @param    int    $limit_ende  Endwert fr die Bltterfunktion
   * @return   array
   * @access   public
   */
  public function getLimitedIDs($limit_start, $limit_ende)
  {
    $res = $this->output->sql->query("
      SELECT
        news.id as newsid
      FROM
        {$this->expblog_news}
      AS
        news
      WHERE
        news.userid = {$this->userid}
      OR
        {$this->userlevel} > 0
      GROUP BY
        news.id
      ORDER BY
        news.id
      DESC
      LIMIT
        {$limit_start},{$limit_ende}
    ");
    return $res;
  }

  /**
   * Funktion zum Ermitteln der Anzahl aller zu einem Benutzer gehrender Artikel.
   *
   * @return   int
   * @access   public
   */
  public function countAll()
  {
    $res = $this->output->sql->query("
      SELECT
        COUNT(id)
      FROM
        {$this->expblog_news}
      WHERE
        userid = {$this->userid}
      OR
        {$this->userlevel} > 0
    ");
    return $res[0][0];
  }

  /**
   * Funktion zum Ermitteln der Anzahl aller zu einem Benutzer gehrender Artikel in der Warteschlange.
   *
   * @return   int
   * @access   public
   */
  public function countAllWS()
  {
    $res = $this->output->sql->query("
      SELECT
        COUNT(id)
      FROM
        {$this->expblog_warteschlange}
      WHERE
        userid = {$this->userid}
      OR
        {$this->userlevel} > 0
    ");
    return $res[0][0];
  }

  /**
   * Reloadsperre: Funktion zum Vergleichen des eingegebenen Titels mit dem des letzten Datensatzes.
   *
   * @param    string    $artikel_titel Eingegebener Titel des Artikels
   * @return   bool
   * @access   public
   */
  public function checkLast($artikel_titel)
  {
    $res = $this->output->sql->query("
      SELECT
        titel
      FROM
        {$this->expblog_news}
      ORDER BY
        id DESC
      LIMIT
        1
    ");

    // Vergleich von $checkme mit dem letzten Datensatz
    if($artikel_titel == $res[0][0])
    {
      return true;
    }
    else
    {
      return false;
    }
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>