<?php
/**
 * Bilder Klasse
 *
 * Diese Klasse stellt den Bilderupload zur Verfgung.
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski (based on TMY's Captcha. Danke btw!)
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.3
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class BILDER
{
  /**
   * Qualitaet von JPEG Bildern
   * @var int
   */
  private $jpgquality = 90; 
  /**
   * Breite der Thumbnails
   * @var int
   */
  private $thumb_width = 75;
  /**
   * Hhe der Thumbnails
   * @var int
   */
  private $thumb_height = 75;
  
  /**
   * Konstruktor
   *
   * @return   void
   * @access   public
   */
  public function __construct() {}
  
  /**
   * Upload Funktion fr Bilder.
   *
   * @param    string $savepath Pdaf zum Speichern von Bildern und Thumbnails
   * @param    int|oktal $chmod CHMOD der Bilder und Thumbnails (z.B. 0644)
   * @return   void
   * @access   public
   */
  public function upload($savepath, $chmod)
  {
    // Infos zum Original
    $name = $_FILES['upload']['name'];
    $filesize = $_FILES['upload']['size'];
    $tmpfile = $_FILES['upload']['tmp_name']; 
    $error = $_FILES['upload']['error'];
  
    // Grsse des Originals ermitteln
    $info = getimagesize($tmpfile);
    $width = $info[0];
    $height = $info[1];
    $type = $info['mime'];
          
    // Bezugsseite ermitteln
    if($width <= $height)
    {
      $target['sitelenght'] = $width;
    }
    else
    {
      $target['sitelenght'] = $height;
    }
    $target['x'] = 0;
    $target['y'] = 0;
                  
    // Image-Type erkennen
    switch($type) {
      case 'image/jpeg': $ori = imagecreatefromjpeg($tmpfile);
                         $basename = basename($name , ".jpg"); 
                         $new = imagecreatetruecolor($width, $height);
                         $new_thumb = imagecreatetruecolor($this->thumb_width, $this->thumb_height);
                         break;        
      case 'image/png':  $ori = imagecreatefrompng($tmpfile);
                         $basename = basename($name , ".png"); 
                         $new = imagecreatetruecolor ($width, $height);
                         $new_thumb = imagecreatetruecolor($this->thumb_width, $this->thumb_height);
                         break;
      case 'image/gif':  $ori = imagecreatefromgif($tmpfile);
                         $basename = basename($name , ".gif");
                         $new = imagecreate($width, $height);
                         $new_thumb = imagecreate($this->thumb_width, $this->thumb_height);
                         break;
      default:           return false;
    }
      
    // Image & Thumbnail erzeugen
    imagecopyresized($new, $ori, 0, 0, 0, 0, $width, $height, $width, $height);
    imagecopyresampled($new_thumb, $ori,  0, 0, $target['x'], $target['y'], $this->thumb_width, $this->thumb_height, $target['sitelenght'], $target['sitelenght']);     
    
    // Images schreiben und Rechte setzten
    switch($type) {
      case 'image/jpeg': imagejpeg($new, $savepath.'images/'.$basename.".jpg", $this->jpgquality);
                         imagejpeg($new_thumb, $savepath.'thumbs/'.$basename.".thb.jpg", $this->jpgquality);
                         chmod($savepath.'thumbs/'.$basename.".thb.jpg", $chmod);
                         break;
      case 'image/gif':  imagegif($new, $savepath.'images/'.$basename.".gif");
                         imagegif($new_thumb, $savepath.'thumbs/'.$basename.".thb.gif");
                         chmod($savepath.'thumbs/'.$basename.".thb.gif", $chmod);
                         break;
      case 'image/png':  imagepng($new, $savepath.'images/'.$basename.".png");
                         imagepng($new_thumb, $savepath.'thumbs/'.$basename.".thb.png");
                         chmod($savepath.'thumbs/'.$basename.".thb.png", $chmod);
                         break;
      default:           return false;
    }       
  
    return true;    
  }
      
  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
  
}
?>