<?php
/**
 * CHMOD Basisklasse
 *
 * Klasse zum ndern von Dateirechten. 
 * @package     Expblog
 * @category    Installer|Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class CHMOD
{
  /**
   * Pfad zu Datei oder Ordner
   * @var string
   */
  public $file;
  /**
   * Der wirklich CHMOD
   * @var string
   */
  public $real_chmod;
  /**
   * Der gewnschte CHMOD
   * @var string
   */
  public $needed_chmod;
  /**
   * Wurde der CHMOD erfolgreich gendert?
   * @var string
   */
  public $success = false;
  /**
   * Flag ob der tatschliche CHMOD >= dem gewnschten
   * @var int
   */
  public $status;

  /**
   * Konstruktor
   *
   * @param    string $file Pfad zu Datei oder Ordner
   * @param    int    $needed_chmod gewnschter CHMOD(in Oktalzahlen, z.B. 0644 oder 0755)
   * @return   void
   * @access   public
   */
  public function __construct($file, $needed_chmod)
  {
    $this->file = $file;
    $this->needed_chmod = $needed_chmod;
    #$this->changeCHMOD();
    $this->status = $this->getStatus();
  }

  /**
   * Funktion zum Auslesen des aktuellen CHMOD's.
   *
   * @return   int
   * @access   public
   */
  public function getCHMOD()
  {
    if(file_exists($this->file))
    {
      @ clearstatcache();
      return (int) substr(decoct(fileperms($this->file)), -3);
    }
    return 0;
  }

  /**
   * Funktion zum ndern des CHMOD's.
   *
   * @return   bool
   * @access   public
   */
  public function setCHMOD()
  {
    if($this->success = chmod($this->file, $this->needed_chmod))
    {
      $this->changeCHMOD();
      $this->setStatus(); // status berprfen
    }
    return $this->success;
  }

  /**
   * Funktion zum berprfen des tatschlichen mit gewnschtem CHMOD.
   *
   * @return   int
   * @access   public
   */
  public function checkStatus()
  {
    if (file_exists($this->file))
    {
      $this->changeCHMOD();
      if($this->real_chmod >= (int) decoct($this->needed_chmod))
      {
        return 2;
      }
      return 1;
    }
    return 0;
  }

  /**
   * Methode zum Aktualisieren des Statusflags.
   *
   * @return   void
   * @access   public
   */
  private function setStatus()
  {
    $this->status = $this->checkStatus();
  }

  /**
   * Methode zum Ausgeben des aktuellen Status Flags.
   *
   * @return   int
   * @access   public
   */
  public function getStatus()
  {
    return $this->checkStatus();
  }

  /**
   * Methode zum Ermitteln des aktuellen CHMOD's.
   *
   * @return   void
   * @access   public
   */
  public function changeCHMOD()
  {
    $this->real_chmod = $this->getCHMOD();
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>