<?php
/**
 * Kommentare Handler Klasse
 *
 * Diese Klasse bietet alle ntigen Werkzeuge um...
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class COMMENTS extends OUTPUT {

  /**
   * Konstruktor
   *
   * @param    array $expconf Kopie der Blogkonfiguration
   * @return   void
   * @access   public
   */
  public function __construct($expconf)
  {
    parent::__construct($expconf);
    $this->connectSQL();
  }


  /**
   * Liefert alle Kommentare zu einer News.
   *
   * @param    int $newsid Artikel/Post ID zu der die Kommentare ausgelesen werden soll
   * @param    int $limit Wert zur Begrenzung der Kommentare
   * @param    int $offset Startposition (fuer die Blaetterfunktion)
   * @return   array|bool
   * @access   public
   */
  public function getComments($newsid)
  {
    $res = $this->sql->query("
                  SELECT
                    *
                  FROM
                    ".DB_TABLE_kommentare."
                  WHERE
                    news = {$newsid}
                  ORDER BY
                    timestamp
                  ASC
    ");
    if($res === false)
    {
      return false;
    }
  	return $res;
  }


  /**
    * Funktion zum Einfuegen neuer Kommentare.
    *
    * @return   void
    * @access   public
    */
  public function addComment($news, $parentid, $kommentar, $name, $timestamp, $ip, $homepage)
  { 
    if(!$this->isURL($homepage) || $homepage == "http://www.example.com")
    {
      $homepage = '';
    }      
    $res = $this->sql->query("
      INSERT INTO
        ".DB_TABLE_kommentare."
      (news, parentid, kommentar, name, timestamp, ip, homepage)
      VALUES
      (
        ".intval($news).",
        ".intval($parentid).",
        '".$this->sql->checkSql(htmlentities($kommentar))."',
        '".$this->sql->checkSql(htmlentities($name))."',
        ".intval($timestamp).",
        '".$this->sql->checkSql($ip)."',
        '".$this->sql->checkSql(htmlentities($homepage))."'
      )
    ");    
    if($res === false)
    {
      return false;
    }
    if($this->config['mailbenachrichtigung'])
    {
      $this->mailme(intval($news), $kommentar);
    }
    return true;            
  }
  
  /**
    * Funktion zum Versendenden der Mailbenachrichtigung bei neuen Kommentaren
    *
    * @return   void
    * @access   private
    */
  private function mailme($news_id, $kommentar) 
  {    
    $subject = 'Neuer Kommentar im Blog!';
    if($this->config['modrewrite'])
    {
      $news_data = $this->sql->query("
        SELECT 
          titel as titel,
          timestamp as timestamp
        FROM
          ".DB_TABLE_news."
        WHERE
          id = {$news_id}
      ");            
      $link = WEBPATH.'archiv/'.date("Y", $news_data[0]['timestamp']).'/'.date("m", $news_data[0]['timestamp']).'/'.date("d", $news_data[0]['timestamp']).'/'.$news_id.'-'.$this->string2urlstring($news_data[0]['titel']);    
    }
    else
    {
      $link = WEBPATH.'details.php?id='.$news_id;
    }  
    $message = "Es wurde ein neuer Kommentar zum Beitrag " . $link . " gepostet.";
    $header = 'From: Expblog Mailbenachrichtigung ' . "\r\n" . 'X-Mailer: PHP/' . phpversion();
    // Fr HTML Mails und Ausgabe des kommentars
    $header .= "Content-Type: text/plain \r\n";
    $header .= "Content-Transfer-Encoding: 8bit \r\n";
    $message .= "\r\n\r\n" . wordwrap(str_replace("\\r\\n", "\r\n", html_entity_decode($kommentar)), 80);
     mail($this->config['mailbenachrichtigung_email'], $subject, $message, $header);
  }


  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}

}
?>