<?php
/**
 * Header Klasse (Ausgabe des Dateikopfes)
 *
 * Diese Klasse erweitert die Outputklasse um alle Werkzeuge fr die Detailansicht
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.3
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class HEADER extends OUTPUT
{
  /**
   * Der Pfad zum aktuell verwendeten Template
   * @var string
   */
  public $stylepath;
  /**
   * Array mit allen .css Dateien des aktuellen Templates
   * @var array
   */
  public $stylefiles;

  /**
   * Konstruktor
   *
   * @param    array $expconf Kopie der Blogkonfiguration(system/expconf.php)
   * @return   void
   * @access   public
   */
  public function __construct($expconf)
  {
    parent::__construct($expconf);
    $this->connectSQL();
    $this->setStylepath();
    $this->stylefiles = $this->getStylefiles();
  }

  /**
   * Funktion zum Ermitteln der Metadaten fr den Seitentitel(Meta Title).
   *
   * @param    int $sortmode Sortiermodus (1=kategorie;2=autor;3=day)
   * @return   string
   * @access   public
   */
  public function getMetaBlogtitel($metamode=0)
  {    
    $blogtitel = $this->config['blogtitel'];
    if( (isset($_GET['e']) && !empty($_GET['e'])) || (isset($_GET['id']) && is_numeric($_GET['id'])) )
    {     
      if($this->config['modrewrite'])
      {
        list($id, $titel) = explode("-", $_GET['e'], 2);              
      }
      else
      {
        $id = $_GET['id'];                
      }          
      $id = intval($id);       
      if($id > 0)  
      {      
        $res = $this->sql->query("SELECT titel FROM ".DB_TABLE_news." WHERE id = {$id}");    
        if($res)
        {
          $blogtitel = $res[0][0].' &bull; '.$this->config['blogtitel'];
        }
      }
    }
    return $blogtitel;
  }

  /**
   * Funktion zum Auslesen aller CSS Dateien des verwendeten Templates
   *
   * @return   array
   * @access   public
   */
  public function getStylefiles()
  {
    $stylefiles = array();
    $stylepath = $this->config['style_dir'].$this->config['style'].'/';
    if(!$handle =  @ opendir($stylepath))
    {
      return false;
    }
    else
    {
      while(false !== ($file = readdir($handle)))
      {
        if($file != "." && $file != "..")
        {
          @ list($filename, $filetype) = explode(".", $file);
          if($filetype == "css")
          {
            array_push($stylefiles, $filename);
          }
        }
      }
      closedir($handle);
    }

    return $stylefiles;
  }

  /**
   * Funktion zum Setzen der URL zum Templateverzeichnis
   *
   * @return   void
   * @access   private
   */
  private function setStylepath()
  {
    $this->stylepath = WEBPATH.$this->config['style_dir'].$this->config['style'].'/';
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>