<?php
/**
 * Hitcounter Klasse erweitert Output
 *
 * Diese Klasse bietet alles was der Hitcounter bentigt.
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class HITCOUNTER extends OUTPUT
{
  /**
   * Kopie von DB_TABLE_news
   * @var string
   */
  private $expblog_news;
  /**
   * Kopie von DB_TABLE_counter
   * @var string
   */
  private $expblog_counter;
  /**
   * Zeitsperre der IP pro Artikel in Sekunden (86400=24h)
   * @var int
   */
  public  $bantime = 86400;
  /**
   * Zeitstempel/Timestamp des Aufrufs
   * @var int
   */
  public  $timestamp;
  /**
   * IP des Besuchers
   * @var string
   */
  public  $ip;

  /**
   * Konstruktor
   *
   * @param    array $expconf Kopie der Blogkonfiguration
   * @return   void
   * @access   public
   */
  public function __construct($expconf)
  {
    parent::__construct($expconf);
    $this->connectSQL();
    $this->expblog_news = DB_TABLE_news;
    $this->expblog_counter = DB_TABLE_counter;
    $this->timestamp = time();
    $this->ip = $_SERVER['REMOTE_ADDR'];
    $this->removeOld();
  }

  /**
   * Funktion um einen neuen Aufruf zu zaehlen
   *
   * @param    int $newsid ID des Artikels
   * @return   void
   * @access   public
   */
  public function addHit($newsid)
  {
    $this->add2Counter($newsid);
    $this->inkrementHits($newsid);
  }

  /**
   * Funktion zum Erhhen(Inkrementieren) um 1 des Zhlerstands eines Artikels
   *
   * @param    int $newsid ID des Artikels
   * @return   void
   * @access   private
   */
  private function inkrementHits($newsid)
  {
    $res = $this->sql->query("
      UPDATE
        {$this->expblog_news}
      SET
        hits = hits+1
      WHERE
        id   = {$newsid}
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion Hinzufgen eines Countereintrags
   *
   * @param    int $newsid ID des Artikels
   * @return   bool
   * @access   private
   */
  private function add2Counter($newsid)
  {
    $res = $this->sql->query("
      INSERT INTO
        {$this->expblog_counter}
      (timestamp, ip, newsid)
      VALUES
      (
        {$this->timestamp},
        '{$this->ip}',
        {$newsid}
      )
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum berprfen ob ein User schon getrackt wurde
   *
   * @param    int $newsid ID des Artikels
   * @return   bool
   * @access   public
   */
  public function checkIfBlocked($newsid)
  {
    $res = $this->sql->query("
      SELECT
        id
      FROM
        {$this->expblog_counter}
      WHERE
        timestamp > {$this->timestamp} - {$this->bantime}
      AND
        newsid    = {$newsid}
      AND
        ip    = '{$this->ip}'
    ");
    if(count($res[0]) != 1)
    {
      return false;
    }
    return true;
  }

  /**
   * Funktion zum Lschen alter Hitcounter Eintrge
   *
   * @return   void
   * @access   private
   */
  private function removeOld()
  {
    $res = $this->sql->query("
      DELETE FROM
        {$this->expblog_counter}
      WHERE
        timestamp < {$this->timestamp}-{$this->bantime}
    ");
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>