<?php
/**
 * Kategorien Basisklasse.
 *
 * Diese Klasse bietet alle ntigen Werkzeuge um die Kategorien auszulesen und zu verwalten.
 * Wird von Front- und Backend genutzt.
 * @package     Expblog
 * @category    Frontend|Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class KATEGORIEN
{
  /**
   * Kopie von DB_TABLE_kategorien
   * @var string
   */
  private $expblog_kategorien;
  /**
   * Kopie von DB_TABLE_news
   * @var string
   */
  private $expblog_news;
  /**
   * Kopie von DB_TABLE_kommentare
   * @var string
   */
  private $expblog_kommentare;
  /**
   * Benutzerlevel des Autors / Kopie $_SESSION['userlevel']
   * @var int
   */
  public  $userlevel;
  /**
   * Referenz auf das $output Objekt des Blogs
   * @var reference|object
   */
  public  $output;

  /**
   * Konstruktor
   *
   * @param    reference|object $output Referenz auf das $output Objekt des Blogs
   * @return   void
   * @access   public
   */
  public function __construct($output)
  {
    $this->output = $output;
    $this->expblog_kategorien = DB_TABLE_kategorien;
    $this->expblog_news = DB_TABLE_news;
    $this->expblog_kommentare = DB_TABLE_kommentare;
    $this->userlevel = $_SESSION['userlevel'];
  }

  /**
   * Funktion zum Hinzufgen einer Kategoerie. Es wird berprft ob der
   * Kategoriename bereits existiert.
   *
   * @param    string $kategorie_name Name der anzulegenden Kategorie
   * @return   bool
   * @access   public
   */
  public function add($kategorie_name)
  {
    if(!$this->katExists($kategorie_name))
    {
      $res = $this->output->sql->query("
          INSERT INTO
            {$this->expblog_kategorien}
          (
            name
          )
          VALUES
          (
            '{$kategorie_name}'
          )
      ");
      if(is_array($res) || $res === true)
      {
        return true;
      }
      return false;
    }
    else
    {
      return false;
    }
  }

  /**
   * Funktion zum berprfen ob ein Kategoriename bereits existiert.
   *
   * @param    string $kategorie_name Name der zu berprfenden Kategorienamens
   * @return   bool
   * @access   public
   */
  public function katExists($kategorie_name, $retres=false)
  {
    $res = $this->output->sql->query("
        SELECT
          id
        FROM
          {$this->expblog_kategorien}
        WHERE
          name  = '{$kategorie_name}'
    ");
    if(is_array($res) && !empty($res))
    {
      if($retres === true)
      {
        return $res[0]['id'];
      }
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Lschen einer Kategorie
   *
   * @param    int $kategorie_id ID der zu lschenden Kategorie
   * @return   bool
   * @access   public
   */
  public function delete($kategorie_id)
  {
    #$res1 = $this->moveArtikel($kategorie_alt, $kategorie_neu) //TODO!
    $res = $this->output->sql->query("
        DELETE FROM
          {$this->expblog_kategorien}
        WHERE
          id = {$kategorie_id}
        AND
          {$this->userlevel} > 1
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /* Mehrere Kategorien loeschen */
  public function multiDelete($kategorien_ids)
  {
    $res = $this->output->sql->query("
        DELETE FROM
          {$this->expblog_kategorien}
        WHERE
          id
        IN
          ({$kategorien_ids})
        AND
          {$this->userlevel} > 1
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /* Kategorie updaten */
  public function update($kategorie_id, $kategorie_name)
  {
    $query = "
        UPDATE
          {$this->expblog_kategorien}
        SET
          name = '{$kategorie_name}'
        WHERE
          id = {$kategorie_id}
        AND
          {$this->userlevel} > 1
    ";

    if(false !== ($this->output->sql->query($query)))
    {
      return true;
    }
    return false;
  }

  /* Kategorie updaten */
  public function moveArtikel($kategorie_id_alt, $kategorie_id_neu)
  {
    $res = $this->output->sql->query("
         UPDATE
           {$this->expblog_news}
         SET
           kategorie = {$kategorie_id_neu}
         WHERE
           kategorie = {$kategorie_id_alt}
         AND
           {$this->userlevel} > 1
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false; 
  }

  /* Kategorien auslesen */
  public function get()
  {
    $res = $this->output->sql->query("
        SELECT
          kategorie.id AS id,
          kategorie.name AS name,
          COUNT(news.id) AS news,
          COUNT(kommentare.id) AS kommentare
        FROM
          {$this->expblog_kategorien} AS kategorie
        LEFT JOIN
          {$this->expblog_news} AS news
        ON
          news.kategorie = kategorie.id
        LEFT JOIN
          {$this->expblog_kommentare} AS kommentare
        ON
          kommentare.news = news.id
        WHERE
          {$this->userlevel} > 1
        GROUP BY
          kategorie.id
    ");
    if($res)
    {
      return $res;
    }
    else
    {
      return false;
    }
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>