<?php
/**
 * Kommentar Klasse.
 *
 * Diese Klasse bietet alle ntigen Werkzeuge um die Kommentare auszulesen und zu verwalten.
 * @package     Expblog
 * @category    Frontend|Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.2
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class KOMMENTARE
{
  /**
   * Kopie von DB_TABLE_kategorien
   * @var string
   */
  private $expblog_kategorien;
  /**
   * Kopie von DB_TABLE_news
   * @var string
   */
  private $expblog_news;
  /**
   * Kopie von DB_TABLE_user
   * @var string
   */
  private $expblog_user;
  /**
   * Benutzer ID / Kopie von $_SESSION['userid']
   * @var int
   */
  public  $userid;
  /**
   * Benutzerlevel des Autors / Kopie $_SESSION['userlevel']
   * @var int
   */
  public  $userlevel;
  /**
   * Referenz auf das $output Objekt des Blogs
   * @var reference|object
   */
  private $output;

  /**
   * Konstruktor
   *
   * @param    reference|object $output Referenz auf das $output Objekt des Blogs
   * @return   void
   * @access   public
   */
  public function __construct($output)
  {
    $this->output = $output;
    $this->expblog_kommentare = DB_TABLE_kommentare;
    $this->expblog_news = DB_TABLE_news;
    $this->expblog_user = DB_TABLE_user;
    $this->userid = $_SESSION['userid'];
    $this->userlevel  = $_SESSION['userlevel'];
  }

  /**
   * Funktion zum Hinzufgern eines Kommentares
   *
   * @param    int    $news_id   ID des Artikels zu dem der Kommentar gehrt
   * @param    int    $pid       ID des Elternkommentars (fr sptere Threadansicht; wird momentan nicht genutzt)
   * @param    string $kommentar Der Kommentar-Text
   * @param    string $name      Der Nickname des Kommentators
   * @param    int    $timestamp Zeitstempel der Erstellung des Artikels
   * @param    string $ip        IP des Kommentators
   * @param    string $homepage  Homepage des Kommentators. Optionale Angabe
   * @return   bool
   * @access   public
   */
  public function add($news_id, $pid, $kommentar, $name, $timestamp, $ip, $homepage)
  {
    $res = $this->output->sql->query("
        INSERT INTO
          {$this->expblog_kommentare}
        SET
          news      = '{$news_id}',
          parentid  = '{$pid}',
          kommentar = '{$kommentar}',
          name      = '{$name}',
          timestamp = '{$timestamp}',
          ip        = '{$ip}',
          homepage  = '{$homepage}'
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Updaten eines Kommentares
   *
   * @param    int    $id        ID des Kommentars der geupdated werden soll
   * @param    int    $news_id   ID des Artikels zu dem der Kommentar gehrt
   * @param    int    $pid       ID des Elternkommentars (fr sptere Threadansicht; wird momentan nicht genutzt)
   * @param    string $kommentar Der Kommentar-Text
   * @param    string $name      Der Nickname des Kommentators
   * @param    int    $timestamp Zeitstempel der Erstellung des Artikels
   * @param    string $ip        IP des Kommentators
   * @param    string $homepage  Homepage des Kommentators. Optionale Angabe
   * @return   bool
   * @access   public
   */
  public function update($id, $news_id, $pid, $kommentar, $name, $timestamp, $ip, $homepage)
  {
    $res = $this->output->sql->query("
        UPDATE
          {$this->expblog_kommentare}
        SET
          news      = '{$news_id}',
          parentid  = '{$pid}',
          kommentar = '{$kommentar}',
          name      = '{$name}',
          timestamp = '{$timestamp}',
          ip        = '{$ip}',
          homepage  = '{$homepage}'
        WHERE
          id = {$id}
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Updaten des Textes eines Kommentares
   *
   * @param    int    $id        ID des Kommentars der geupdated werden soll
   * @param    string $kommentar Der Kommentar-Text
   * @return   bool
   * @access   public
   */
  public function updateSimple($id, $kommentar)
  {
    $valid = $this->checkOwner($id);
    $res = $this->output->sql->query("
        UPDATE
          {$this->expblog_kommentare}
        SET
          kommentar = '{$kommentar}'
        WHERE
          id = {$id}
        AND
        (
          {$valid} = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

  /**
   * Funktion zum Ermitteln zu welchem Benutzer ein Kommentar gehrt
   *
   * @param    int $id ID des Kommentars der geupdated werden soll
   * @return   int
   * @access   public
   */
  private function checkOwner($id)
  {
    $res = $this->output->sql->query("
        SELECT
          news.userid
        FROM
          {$this->expblog_kommentare} AS kommentare
        LEFT JOIN
          {$this->expblog_news} AS news
        ON
          news.id = kommentare.news
        WHERE
          kommentare.id = {$id}
    ");
    if(is_array($res))
    {
      return $res[0][0];
    }
    return '0';
  }

  public function delete($id)
  {
    $owner = $this->checkOwner($id);
    $res = $this->output->sql->query("
        DELETE FROM
          {$this->expblog_kommentare}
        WHERE
          id = {$id}
        AND
        (
          {$owner} = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
    ");
    if(is_array($res) || $res === true)
    {
      return true;
    }
    return false;
  }

//  function multiDelete($ids)
//  {
//    $valid = @ mysql_result($this->checkOwnerMulti($ids), 0);
//    $res = sql("
//        DELETE FROM
//          {$this->expblog_kommentare}
//        WHERE
//          id
//        IN
//          ({$ids})
//        AND
//        (
//          {$valid} = {$this->userid}
//        OR
//          {$this->userlevel} > 0
//        )
//    ",true);
//  }

  public function get($artikelid)
  {
    $res = $this->output->sql->query("
        SELECT
          kommentare.*,
          news.*
        FROM
          {$this->expblog_kommentare} AS kommentare
        LEFT JOIN
          {$this->expblog_news} AS news
        ON
          kommentare.news = news.id
        LEFT JOIN
          {$this->expblog_user} AS user
        ON
          news.userid = user.id
        WHERE
          news = {$artikelid}
        AND
        (
          news.userid = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
        GROUP BY
          kommentare.id
        ORDER BY
          kommentare.id
        DESC
    ");

    return $res;
  }

  public function getLimited($limit_start, $limit_ende)
  {
    $res = $this->output->sql->query("
        SELECT
          kommentare.*,
          news.*
        FROM
          {$this->expblog_kommentare} AS kommentare
        LEFT OUTER JOIN
          {$this->expblog_news} AS news
        ON
          kommentare.news = news.id
        LEFT OUTER JOIN
          {$this->expblog_user} AS user
        ON
          news.userid = user.id
        WHERE
        (
          news.userid = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
        GROUP BY
          kommentare.id
        ORDER BY
          kommentare.id
        DESC
        LIMIT
        {$limit_start},{$limit_ende}
    ");

    return $res;
  }


  public function getAll()
  {
    $res = $this->output->sql->query("
        SELECT
          kommentare.*,
          news.*
        FROM
          {$this->expblog_kommentare} AS kommentare
        LEFT JOIN
          {$this->expblog_news} AS news
        ON
          kommentare.news = news.id
        LEFT JOIN
          {$this->expblog_user} AS user
        ON
          news.userid = user.id
        WHERE
        (
          news.userid = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
        GROUP BY
          kommentare.id
        ORDER BY
          kommentare.id
        DESC
    ");

    return $res;
  }

  public function getSingle($id)
  {
    $res = $this->output->sql->query("
        SELECT
          kommentare.*
        FROM
          {$this->expblog_kommentare} AS kommentare
        LEFT JOIN
          {$this->expblog_news} AS news
        ON
          kommentare.news = news.id
        LEFT JOIN
          {$this->expblog_user} AS user
        ON
          news.userid = user.id
        WHERE
          kommentare.id = {$id}
        AND
        (
          news.userid = {$this->userid}
        OR
          {$this->userlevel} > 0
        )
    ");

    return $res;
  }


  public function countAll()
  {
    $res = $this->output->sql->query("
        SELECT
          kommentare.*
        FROM
          {$this->expblog_kommentare} AS kommentare
        LEFT JOIN
          {$this->expblog_news} AS news
        ON
          kommentare.news = news.id
        WHERE
          news.userid = {$this->userid}
        OR
          {$this->userlevel} > 0
    ");

    return mysql_num_rows($res);
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>