<?php
/**
 * MYSQL Basisklasse
 *
 * Diese Klasse bietet alle ntigen Werkzeuge um...
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.3
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class MYSQL extends DATABASE {

  /**
   * Konstruktor
   *
   * @return   void
   * @access   public
   */
  public function __construct() {}


  /**
   * Funktion zum Aufbaut die Verbindung zum MYSQL Server.
   *
   * @param    string $database Dateiname der zu benutzenden Datenbank
   * @param    string $host MYSQL Hostname (meist localhost)
   * @param    string $username MYSQL Benutzername (gibts vom Webhoster)
   * @param    string $password MYSQL Passwort (gibts auch vom Webhoster)
   * @return   bool
   * @access   public
   */
  public function connect($database, $host, $username, $password)
  {
    if(false === ($this->db_link = @ mysql_connect($host, $username, $password)))
    {
      echo '<pre class="sql_debugging">Datenbankfehler '.mysql_errno($this->db_link).': '.mysql_error($this->db_link).'</pre>';
      return false;
    }
    elseif(false === ($select_db = $this->selectDB($database)))
    {
      return false;
    }
    
    if(version_compare($this->version($this->db_link), '4.1.0', '<'))
    {
      $this->query("SET NAMES latin1"); // Kompatibilitaet zu aelteren MySQL Versionen als 4.1 herstellen
    }
    return true;
  }


  /**
   * Funktion zum Selektieren der Datenbank.
   *
   * @param    string $database String mit dem Namen der zu benutzenden Datenbank
   * @return   bool
   * @access   public
   */
  public function selectDB($database)
  {
    if(false === ($select_db = @ mysql_select_db($database)))
    {
      echo '<pre class="sql_debugging">Datenbankfehler '.mysql_errno($this->db_link).': '.mysql_error($this->db_link).'</pre>';
      return false;
    }
    return true;
  }


  /**
   * Funktion zur Datenbankabfrage.
   *
   * @param    string $statement String mit dem SQL Query
   * @param    bool $debug Optionaler Parameter fuer Debugging (Ausgabe des Querys)
   * @return   resource|bool
   * @access   public
   */
  public function query($statement, $debug=false)
  {
    // Debug
    if($debug)
    {
      echo '<pre class="sql_debugging">'.$statement.'</pre>';
    }
    
    // Fehler
    if(false === ($res = @ mysql_query($statement, $this->db_link)))
    {
      echo '<pre class="sql_debugging">Datenbankfehler '.mysql_errno($this->db_link).': '.mysql_error($this->db_link).'<br />'.$statement.'</pre>';
      return false;
    }
       
    // is resource
    if(is_resource($res))
    {
      $result = array();
      while($row = @ mysql_fetch_array($res))      
      {
        array_push($result, $row);
      }
      return $result;
    }
    
    return true;
  }
      
  
  /**
   * Funktion zum Validieren von Eingabe-Strings welche direkt in einem SQL-Query genutzt werden
   * Ungeprfte Eingaben sollten auf keinen Fall verwendet werden! (Schutz vor SQL Injection)
   *
   * @param    string $value String mit der Usereingabe, welche zu berprfen ist.
   * @return   string
   * @access   public
   */
  public function checkSql($value)
  {    
    // stripslashes, falls ntig
    if (get_magic_quotes_gpc())
    {
      $value = stripslashes($value);
    }

    // quotieren, falls kein Integer
    if (!is_int($value))
    {
      $value = mysql_real_escape_string($value);
    }
    
    return $value;
  }


  /**
   * Funktion zum Schliessen der Verbindung zum MYSQL Server.
   *
   * @param    resource $link Verbindungs-Kennung (Link) der MYSQL Verbindung zum Server
   * @return   bool
   * @access   public
   */
  public function close($link)
  {
    if(false === ($close = @ mysql_close($link)))
    {
      echo '<pre class="sql_debugging">Datenbankfehler '.mysql_errno($this->db_link).': '.mysql_error($this->db_link).'</pre>';
      return false;
    }
    return true;
  }


  /**
   * Ausgabe der SQL Server Version.
   *
   * @param    resource $link Verbindungs-Kennung (Link) der Verbindung zum Server
   * @return   string
   * @access   public
   */
  public function version($link)
  {
    return mysql_get_server_info($link);
  }


  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}

}
?>
