<?php
/**
 * RSS Basisklasse
 *
 * Diese Klasse erstellt und bearbeitet den RSS Feed Version 0.91.
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6.3
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class RSS
{
  /**
   * Name der News Tabelle / Kopie von DB_TABLE_news
   * @var string
   */
  private $expblog_news;
  /**
   * Referenz zum $output Objekt
   * @var reference|object
   */
  private $output;
  /**
   * Zeitstempel
   * @var int
   */
  public $timestamp;
  /**
   * Max. Anzahl der Posts im Feed 
   * @var int
   */
  public $limit = 50;


  /**
   * Konstruktor
   *
   * @param    reference|object $output Referenz zum $output Objekt
   * @param    int $limit Maximale Anzahl der Artikel im Feed (Fallback=50)
   * @return   void
   * @access   public
   */
  public function __construct($output)
  {
    $this->output = $output;
    $this->expblog_news = DB_TABLE_news;
    $this->timestamp = time();
  }

  /**
   * RSS Feed (RSS 0.91) erzeugen
   *
   * @return   bool
   * @access   public
   */
  public function makeFeed()
  {
    if($this->output->config['rssstatus'])
    {
      // RSS Datei
      $rssfile = "rss.xml";    
      
      // Absoluten Pfad ermitteln, abhaengig vom Betriebssystem
      if(file_exists(ABSPATH.$rssfile))
      {
        $rsspath = ABSPATH.$rssfile;
      }
      elseif(file_exists(ABSPATH.'/'.$rssfile))
      {
        $rsspath = ABSPATH.'/'.$rssfile;
      }
      elseif(file_exists(ABSPATH.'\\'.$rssfile))
      {
        $rsspath = ABSPATH.'\\'.$rssfile;
      }
      else
      {
        return false;
      }
      
      // Feed schreiben
      $xml_header = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\" ?>\n";
      $feed_header = '<rss version="0.91">
          <channel>
            <title>'.stripslashes($this->output->config['rsstitel']).'</title>
            <link>'.WEBPATH.'</link>
            <description>'.stripslashes($this->output->config['rssbeschreibung']).'</description>
            <language>'.$this->output->config['rsssprache'].'</language>
            <copyright>'.$this->output->config['rsscopyright'].'</copyright>
            <pubDate>'.date("D, d M Y H:i:s", $this->timestamp).' GMT</pubDate>';
  
      $res = $this->output->sql->query("
            SELECT
              *
            FROM
              {$this->expblog_news}
            ORDER BY
              timestamp
            DESC
            LIMIT
              {$this->limit}
      ");
  
      $feed = fopen($rsspath, 'wb');
      fputs($feed, $xml_header);
      fputs($feed, $feed_header);
  
      foreach($res as $row => $value)
      {
        $_id = $value[0];
        $_titel = $this->output->htmlnumericentities($value[4]);
        $_teaser = $this->output->htmlnumericentities($value[5]);        
        if($this->output->config['modrewrite'])
        {
          $_link = WEBPATH.'archiv/'.date("Y", $value[1]).'/'.date("m", $value[1]).'/'.date("d", $value[1]).'/'.$_id.'-'.$this->output->string2urlstring($_titel);
        }
        else
        {
          $_link = WEBPATH.'details.php?id='.$_id;
        }
  
        $feeds = '<item>
                  <title>'.$_titel.'</title>
              <description>'.$_teaser.'</description>
            <link>'.$_link.'</link>
            <pubDate>'.date("D, d M Y H:i:s", $value[1]).' GMT</pubDate>
          </item>';
        fputs($feed, $feeds);
      }
  
      $feed_footer = "</channel></rss>";
      fputs($feed, $feed_footer);
      fclose($feed);
  
      return true;
    }
    else
    {
      return false;
    }
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>