<?php
/**
 * Diese Search Klasse stellt die Suchfunktion fr das Expblog zur Verfgung.
 *
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6_1
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class SEARCH extends OUTPUT
{
  /**
   * Kopie von DB_TABLE_news
   * @var string
   */
  private $expblog_news;
  /**
   * Kopie von DB_TABLE_kommentare
   * @var string
   */
  private $expblog_kommentare;
  /**
   * Kopie von DB_TABLE_user
   * @var string
   */
  private $expblog_user;
  /**
   * Kopie von DB_TABLE_kategorien
   * @var string
   */
  private $expblog_kategorien;
  /**
   * Referenz auf das $output Objekt des Blogs
   * @var reference|object
   */
  private $output;

  /**
   * Konstruktor
   *
   * @param    reference|object $output Referenz auf das $output Objekt des Blogs
   * @return   void
   * @access   public
   */
  public function __construct($output)
  {
    $this->output = $output;
    $this->expblog_news = DB_TABLE_news;
    $this->expblog_kommentare = DB_TABLE_kommentare;
    $this->expblog_user = DB_TABLE_user;
    $this->expblog_kategorien = DB_TABLE_kategorien;
  }

  /**
   * Suchfunktion. Durchsucht alle Artikel(Titel,Teaser,Body) nach $needle.
   *
   * @param    string $needle String nachdem das Blog durchsucht werden soll
   * @return   array|bool
   * @access   public
   */
  public function search($needle)
  {
    $search = $this->output->sql->checkSQL(trim($needle));
    if(!empty($search))
    {
      $res = $this->output->sql->query("
          SELECT
            news.*,
            user.name AS username,
            kategorien.name AS kategorie,
            COUNT(kommentare.kommentar) AS counter
          FROM
            {$this->expblog_news} AS news
          LEFT JOIN
            {$this->expblog_kommentare} AS kommentare
          ON
            news.id = kommentare.news
          LEFT JOIN
            {$this->expblog_user} AS user
          ON
            news.userid = user.id
          LEFT JOIN
            {$this->expblog_kategorien} AS kategorien
          ON
            news.kategorie = kategorien.id
          WHERE
            titel LIKE '%{$search}%'
          OR
            (
              teaser LIKE '%".html_entity_decode($search)."%'
            OR
              teaser LIKE '%".htmlentities($search)."%'
            )
          OR
            (
              nachricht LIKE '%".html_entity_decode($search)."%'
            OR
              nachricht LIKE '%".htmlentities($search)."%'
            )
          GROUP BY
            news.id
          ORDER BY
            news.timestamp
          DESC
        ");
        if(is_array($res))
        {
          return $res;
        }
        return false;
      }
      else
      {
        return false;  
      }
  }

  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}
}
?>