<?php
/**
 * SQLite Basisklasse
 *
 * Diese Klasse bietet alle ntigen Werkzeuge um...
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class SQLITE extends DATABASE {

  /**
   * Konstruktor
   *
   * @return   void
   * @access   public
   */
  public function __construct() {}


  /**
   * Funktion zum Aufbaut die Verbindung zur SQLite Datenbank.
   * Exisatiert die Datenbank nicht, wird sie erzeugt. (CHMOD 0666)
   *
   * @param    string $database Dateiname der zu benutzenden Datenbank
   * @param    string $host - wird nicht benutzt -
   * @param    string $username - wird nicht benutzt -
   * @param    string $password - wird nicht benutzt -
   * @return   bool
   * @access   public
   */
  public function connect($database, $host, $username, $password)
  {
    if(false === ($this->db_link = @ sqlite_open($database, 0666, $dberrors)))
    {
      echo '<pre class="sql_debugging">Datenbank Verbindungsfehler</pre>';
      return false;
    }
    $this->query("PRAGMA short_column_names = 1"); // Info dazu unter http://www.sqlite.org/pragma.html
    return true;
  }


  /**
   * Funktion zum Selektieren der Datenbank.
   *
   * @param    string $database String mit dem Namen der zu benutzenden Datenbank
   * @return   bool
   * @access   public
   */
  public function selectDB($database) {}


  /**
   * Funktion zur Datenbankabfrage.
   *
   * @param    string $statement String mit dem SQL Query
   * @param    bool $debug Optionaler Parameter fuer Debugging (Ausgabe des Querys)
   * @return   resource|bool
   * @access   public
   */
  public function query($statement, $debug=false)
  {
    // Debug
    if($debug)
    {
      echo '<pre class="sql_debugging">'.$statement.'</pre>';
    }

    // Fehler
    if(false === ($res = @ sqlite_query($statement, $this->db_link)))
    {
      echo '<pre class="sql_debugging">Datenbankfehler: '.sqlite_last_error($this->db_link).': '.sqlite_error_string(sqlite_last_error($this->db_link)).'<br />'.$statement.'</pre>';
      return false;
    }

    // is resource
    if(is_resource($res))
    {
      $result = array();
      while($row = @ sqlite_fetch_array($res))
      {
        array_push($result, $row);
      }
      return $result;
    }

    return true;
  }


  /**
   * Funktion zum Validieren von Eingabe-Strings welche direkt in einem SQL-Query genutzt werden
   * Ungeprfte Eingaben sollten auf keinen Fall verwendet werden! (Schutz vor SQL Injection)
   *
   * @param    string $value String mit der Usereingabe, welche zu berprfen ist.
   * @return   string
   * @access   public
   */
  public function checkSql($value)
  {
    // stripslashes, falls ntig
    if(get_magic_quotes_gpc())
    {
      $value = stripslashes($value);
    }

    // quotieren, falls kein Integer
    if(!is_int($value))
    {
      $value = sqlite_escape_string($value);
    }
    return $value;
  }


  /**
   * Funktion zum Schliessen der Verbindung zur SQLite Datenbank.
   *
   * @param    resource $link Verbindungs-Kennung (Link) der SQLitw Verbindung
   * @return   bool
   * @access   public
   */
  public function close($link)
  {
    $close = @ sqlite_close($link);
    if(!$close)
    {
      echo '<pre class="sql_debugging">Verbindung zum SQL Server konnte nicht beendet werden: '.mysql_error().'</pre>';
      return false;
    }
    return true;
  }


  /**
   * Liefert die Version der genutzten SQLite-Bibliothek .
   *
   * @param    resource $link Verbindungs-Kennung (Link) der Verbindung zum Server
   * @return   string
   * @access   public
   */
  public function version($link)
  {
    return sqlite_libversion();
  }


  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct()
  {
    #$this->close();
  }

}
?>
