<?php
/**
 * Statistik Klasse
 *
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class STATS
{
  /**
   * Referenz auf das $output Objekt des Blogs
   * @var reference|object
   */
  private $output;

  /**
   * Konstruktor
   *
   * @param    array $expconf Kopie der Blogkonfiguration
   * @return   void
   * @access   public
   */
  public function __construct($output)
  {
    $this->output = $output;
  }


  /**
   * Anzahl aller Artikel
   *
   * @return   array|bool
   * @access   public
   */
  public function countArticles()
  {
    $res = $this->output->sql->query("
      SELECT
        COUNT(id)
      FROM
        ".DB_TABLE_news."
    ");
    if(!$res)
    {
      return false;
    }
    return $res[0][0];
  }


  /**
   * Anzahl aller Kommentare
   *
   * @return   array|bool
   * @access   public
   */
  public function countComments()
  {
    $res = $this->output->sql->query("
      SELECT
        COUNT(id)
      FROM
        ".DB_TABLE_kommentare."
    ");
    if(!$res)
    {
      return false;
    }
    return $res[0][0];
  }


  /**
   * Anzahl aller Kategorien
   *
   * @return   array|bool
   * @access   public
   */
  public function countCategories()
  {
    $res = $this->output->sql->query("
      SELECT
        COUNT(id)
      FROM
        ".DB_TABLE_kategorien."
    ");
    if(!$res)
    {
      return false;
    }
    return $res[0][0];
  }


  /**
   * Funktion zum ermitteln Uptime des Blogs in Tagen.
   *
   * @return   int
   * @access   public
   */
  public function getUptime() {
    $diff = (time() - intval(INITIME)) / (3600*24);
    $uptime = round($diff, 0);
    if($uptime == 1) $uptime .= " Tag";
    else $uptime .= " Tage";
    return $uptime;
  }


  /**
   * Destruktor
   *
   * @return   void
   * @access   public
   */
  public function __destruct() {}

}
?>
