<?php
/**
 * Mailer Klasse
 *
 * @package     Expblog
 * @category    Backend
 * @author      Volker S. Latainski
 * @copyright   Copyright (c) 2008, Volker S. Latainski
 * @version     0.6
 * @license     Freeware (siehe LIZENZ.txt im Hauptverzeichnis)
 * @link        http://www.expblog.net
 * @link        http://www.expblog.de
 * @filesource
 */
class XMAILER {

  /**
   * Zeit nach der weitergeleitet wird
   * @var int
   */
  private $redirect_time = 5;
  /**
   * Seite auf die nach dem Senden einer Mail weitergeleitet werden soll
   * @var string
   */
  private $redirect_url  = WEBPATH.'kontakt.php';
  /**
   * Blogkonfiguration (Kopie von $expconf)
   * @var array
   */
  private $config;


  /**
   * Konstruktor
   *
   * @return   void
   * @access   public
   */
  public function __construct($expconf)
  {
    setlocale(LC_TIME, 'de_DE');
    $this->config = $expconf;
  }


  /**
   * Emailadresse auf Gltigkeit berprfen.
   *
   * @param    string $email Die zu validierende Email Adresse
   * @return   bool
   * @access   private
   */
  private function chkMail($email)
  {
    if(!eregi("^[_a-zA-Z0-9-]+(\.[_a-zA-Z0-9-]+)*@[a-zA-Z0-9-]+\.([a-zA-Z0-9-]{2,4})$",$email))
    {
      return false;
    }
    return true;
  }


  /**
   * Funktion zum Erkennen von E-Mail Injection.
   *
   * @param    string $input Usereingabe aus dem Formular
   * @param    string $element Formularfeld (einzeilig oder Textarea)
   * @return   bool
   * @access   private
   * @todo     Umbau von Black auf Whitelist
   */
  private function spamCheck($input, $element)
  {
    // Textareas
    if($element == "message")
    {
      if(preg_match('/(content-type:|content-transfer-encoding:|mime-version:|subject:|to:|cc:|bcc:)/i', $input))
      {
        return false;
      }
    }
    else
    {
      // einzeilige Eingabefelder
      if(preg_match('/(%0A|%0D|\r\n|\n|\r|content-type:|content-transfer-encoding:|mime-version:|subject:|to:|cc:|bcc:)/i', $input))
      {
        return false;
      }
    }
    return true;
  }


  /**
   * Fehlerausgabe.
   *
   * @param    string $formvar
   * @return   void
   * @access   private
   */
  private function errorReport($formvar)
  {
    switch($formvar)
    {
      case 'name':    $errormsg = "Bitte geben sie einen Namen an ;)";
                      break;
      case 'email':   $errormsg = "Bitte geben Sie eine gltige Email Adresse an ;)";
                      break;
      case 'subject': $errormsg = "Bitte geben sie einen Betreff fr Ihre Mitteilung an ;)";
                      break;
      case 'message': $errormsg = "Bitte geben sie eine Nachricht ein ;)";
                      break;
      case 'spam':    $errormsg = "Hier ist Spammen nicht erlaubt ;)";
                      break;
      default:        $errormsg = "Fehler: Formulareingabe konnte nicht verarbeitet werden. Es wurde keine Mail versandt!";
    }

    echo '<body width="100%" height="100%">';
    echo '<head><meta http-equiv="refresh" content="'.$this->redirect_time.'; URL='.$this->redirect_url.'"><link rel="stylesheet" href="blog.css" type="text/css"></head>';
    echo '<table style="width:100%;height:100%;">';
    echo '<tr>';
    echo '<td height="100%" width="100%" align="center" valign="middle" class="txt">';
    echo '<b>'.$errormsg.'</b><br>';
    echo 'Sie werden in '.$this->redirect_time.' Sekunden weitergeleitet. Klicken Sie <a href="'.$this->redirect_time.'" class=\"txt\"><u>hier</u></a> falls Sie nicht warten mchten...';
    echo '</td></tr></table></body>';
    die();
  }


//  /**
//   * Sicherheitsabfrage / Referer Check
//   *
//   * @return   void
//   * @access   private
//   */
//  private function checkReferer()
//  {
//    if(!$_SERVER['HTTP_REFERER'])
//    {
//      $this->errorReport('referer');
//    }
//  }


  /**
   * Sicherheitsabfrage / Formular Check
   *
   * berprfung ob Felder leer abgesendet wurden, vorhanden sind
   * oder Spam enthalten
   * @return   void
   * @access   private
   */
  private function checkFormElements()
  {
    foreach($_POST as $formarray => $element)
    {
      if(!spamCheck($formarray, $element))
      {
        $this->errorReport('spam');
      }
      elseif(!isset($formarray) || empty($element))
      {
        $this->errorReport($element);
      }
    }
  }


  /**
   * Kontakt Email senden.
   *
   * @param    string $name Name des Users
   * @param    string $email Email-Adresse des Users
   * @param    string $subject Betreff der Nachricht
   * @param    string $message Die Kontaktnachricht
   * @return   ---
   * @access   public
   */
  public function sendContactMail($name, $email, $subject, $message)
  {
    if(!this->chkMail($email))
    {
      $this->errorReport('email');
    }
    elseif()
    {

    }

    $date = strftime("%A, %d-%m-%Y", time());
    $email_subject = "Blog Feedback: " . $subject;
    $email_body = "IP: "  . $_SERVER['REMOTE_ADDR'] . "\n\nVon: " . $name . "\nEmail: " . $email . "\n\nBetreff: " . $subject . "\n\n" . $message;
    $header .= "X-Mailer: PHP/" . phpversion(). "\n";
    $header .= "X-Sender-IP:" . $_SERVER['REMOTE_ADDR'] . "\n";
    $header .= "Content-Type: text/plain";
    mail($this->config['impemail'], $email_subject, $email_body, $header);

    echo '<head><meta http-equiv="refresh" content="'.$this->redirect_time.'; URL='.$this->redirect_url.'"></head>';
    echo '<body width="100%" height="100%">';
    echo '<table style="width:100%;height:100%;">';
    echo '<tr>';
    echo '<td height="100%" width="100%" align="center" valign="middle" class="txt">';
    echo '<b>Danke, Ihr Feedback wurde erfolgreich bermittelt!</b><br />Sie werden in '.$this->redirect_time.' Sekunden weitergeleitet.<br />';
    echo 'Klicken Sie <a href="'.$this->redirect_url.'" title="Weiterleitung">hier</a> falls Sie nicht warten mchten...';
    echo '</td></tr></table></body>';
  }

}
?>
